@@ -7,6 +7,7 @@ from uuid import uuid4
 from flask import Blueprint
 
 from .buddy import Buddy
+from .circleci import CircleCI
 from .codeship import Codeship
 from .coveralls import Coveralls
 from .github import (GitHub, GitHubEnterprise, GitHubEnterpriseIssues,
@@ -16,7 +17,7 @@ from .tracker import Tracker
 from .travis import TravisOS, TravisPro
 
 __author__ = 'Jonathan Sharpe'
-__version__ = '0.10.1'
+__version__ = '0.11.0'
 
 blueprint = Blueprint(
     'services',
@@ -31,6 +32,7 @@ logger = logging.getLogger(__name__)
 # TODO: add services here and in static/scripts/services.js
 SERVICES = dict(
     buddy=Buddy,
+    circleci=CircleCI,
     codeship=Codeship,
     coveralls=Coveralls,
     github=GitHub,
